package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.system.entity.BpmNodeScriptRelevance;

/**
 * 流程节点脚本关联Service接口
 *
 * @author hzh
 * @date 2023-10-26
 */
public interface IBpmNodeScriptRelevanceService {
    /**
     * 查询流程节点脚本关联
     *
     * @param id 流程节点脚本关联主键
     * @return 流程节点脚本关联
     */
    public BpmNodeScriptRelevance selectBpmNodeScriptRelevanceById(Long id);

    /**
     * 查询流程节点脚本关联列表
     *
     * @param bpmNodeScriptRelevance 流程节点脚本关联
     * @return 流程节点脚本关联集合
     */
    public List<BpmNodeScriptRelevance> selectBpmNodeScriptRelevanceList(BpmNodeScriptRelevance bpmNodeScriptRelevance);

    /**
     * 新增流程节点脚本关联
     *
     * @param bpmNodeScriptRelevance 流程节点脚本关联
     * @return 结果
     */
    public int insertBpmNodeScriptRelevance(List<BpmNodeScriptRelevance> bpmNodeScriptRelevance);

    /**
     * 修改流程节点脚本关联
     *
     * @param bpmNodeScriptRelevance 流程节点脚本关联
     * @return 结果
     */
    public int updateBpmNodeScriptRelevance(List<BpmNodeScriptRelevance>  bpmNodeScriptRelevance);

    /**
     * 批量删除流程节点脚本关联
     *
     * @param ids 需要删除的流程节点脚本关联主键集合
     * @return 结果
     */
    public int deleteBpmNodeScriptRelevanceByIds(Long[] ids);

    /**
     * 删除流程节点脚本关联信息
     *
     * @param id 流程节点脚本关联主键
     * @return 结果
     */
    public int deleteBpmNodeScriptRelevanceById(Long id);
}
